OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU information er ikke tilgængeli",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "System" : "System",
    "Monitoring" : "Monitorering",
    "Monitoring app with useful server information" : "Monitoreringsapp med serverinformation",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Viser serverinformation som CPU belastning, RAM forbrug, lagerforbrug, antal brugere osv.",
    "Temperature" : "Temperatur",
    "Load" : "Belastning",
    "Memory" : "Hukommelse",
    "Disk" : "Disk",
    "Size:" : "Størrelse:",
    "Files:" : "Filer:",
    "Storages:" : "Lagre:",
    "Free Space:" : "Ledig plads:",
    "Network" : "Netværk",
    "Active users" : "Aktive brugere",
    "Total users:" : "Antal brugere:",
    "Shares" : "Delinger",
    "Users:" : "Brugere:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Upload max size:" : "Max upload størrelse:",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Eksternt monitoreringsværktøj",
    "Copy" : "Kopier",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Send derefter tokenet med \"NC-Token\"-headeren, når du forespørger på ovenstående URL."
},
"nplurals=2; plural=(n != 1);");
